@@ -15,11 +15,11 @@
 #'        \item{\code{n_interflow [= 1.0]}: Exponent for the determination of interflow.}
 #'        \item{\code{n_baseflow [= 1.0]}: Exponent for the determination of baseflow.}
 #'        \item{\code{num_daily_substeps [= 4]}: Number of daily sub-steps for interflow calculations.}
-#'        \item{\code{channel_flow_speed [= 1]}: Average flow speed in the channel (in m/s).}
 #'        \item{\code{subwatersheds [= FALSE]}: A boolean flag to define watershed subunits.}
 #'        \item{\code{max_overlap [= 0.2]}: Maximum proportion of overlapping cells for watershed subunits to be considered independent. Lower values will normally produce larger subunits.}
 #'        \item{\code{rock_max_infiltration [= 10]}: Maximum infiltration rate (mm·day-1) for rock cells.}
 #'        \item{\code{deep_aquifer_loss [= 0]}: Daily loss rate from watershed aquifer towards a deeper aquifer not connected to outlets (mm·day-1).}
+#'        \item{\code{n_manning [= 0.035]}: Manning's roughness coefficient.}
 #'      }
 #'    }
 #'    \item{\code{serghei_parameters}: A list of SERGHEI parameters with the following elements: 
@@ -48,11 +48,11 @@ default_watershed_control<-function(watershed_model = "tetis") {
     n_interflow = 1.0,
     n_baseflow = 1.0,
     num_daily_substeps = 4,
-    channel_flow_speed = 1,
     subwatersheds = FALSE,
     max_overlap = 0.2,
     rock_max_infiltration = 10,
-    deep_aquifer_loss =  0
+    deep_aquifer_loss =  0,
+    n_manning =  0.035
   )
   serghei_parameters <- list(
     input_dir = "",
